@@ -8,11 +8,12 @@ import pytest
 
 def main(
     testfile: Optional[Path] = None,
-    alignment: Optional[Path] = None,
-    alignment_format: Optional[str] = 'fasta',
+    sequence: Optional[Path] = None,
+    sequence_format: Optional[str] = 'fasta',
     tree: Optional[Path] = None,
     tree_format: Optional[str] = 'newick',
     data: Optional[Path] = None,
+    data_format: Optional[str] = 'csv',
     verbose: bool = False,
     report: Optional[Path] = None,
     expression: str = None,
@@ -22,14 +23,17 @@ def main(
     args = [testfile]
     if not verbose:
         args.extend(["-ra", "--tb=no", "--no-header"])
-    if alignment is not None:
-        args.extend(["--alignment", alignment])
-        args.extend(["--alignment-format", alignment_format])
+    else:
+        args.extend(["-v"])
+    if sequence is not None:
+        args.extend(["--sequence", sequence])
+        args.extend(["--sequence-format", sequence_format])
     if tree is not None:
         args.extend(["--tree", tree])
         args.extend(["--tree-format", tree_format])
     if data is not None:
         args.extend(["--data", data])
+        args.extend(["--data-format", data_format])
     if report:
         if not str(report).endswith('.html'):
             raise ValueError(f"Report must use .html extension.")
